#version 330

uniform sampler2D texEarth, texSpec, texNight, texClouds;
uniform float shininess = 128;

in Data {
	vec4 eye;
	vec2 texCoord;
	vec3 normal;
	vec3 l_dir;
} DataIn;

out vec4 colorOut;

void main() {

	// get texture color
	vec4 EColor = texture(texEarth, DataIn.texCoord);
	vec4 ESpec = texture(texSpec, DataIn.texCoord);
	vec4 ENight = texture(texNight, DataIn.texCoord);
	vec4 EClouds = texture(texClouds, DataIn.texCoord);

	// set the specular term to black
	vec4 spec = vec4(0.0);

	// normalize both input vectors
	vec3 n = normalize(DataIn.normal);
	vec3 e = normalize(vec3(DataIn.eye));

	float intensity = max(dot(n,DataIn.l_dir), 0.0);
	// if the vertex is lit compute the specular color
	if (intensity > 0.0 ) {
		// compute the half vector
		vec3 h = normalize(DataIn.l_dir + e);	
		// compute the specular intensity
		float intSpec = max(dot(h,n), 0.0);
		// compute the specular term into spec
		spec = vec4(1) * pow(intSpec,shininess);
		

	}
	//EClouds = vec4(0.0);
	vec4 night = ENight * (1 - EClouds);
	vec4 day = mix(intensity * EColor + spec * ESpec, vec4(1), EClouds.r);
	float f = smoothstep(intensity, 0.0, 0.1);
	colorOut = mix(night, day, f);
}